==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/InformacjaDodatkowaPoleWpis.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class InformacjaDodatkowaPoleWpis extends GenericDPSObject {
    /**
     * INFORMACJA_DODATKOWA_POLE_WPIS.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * INFORMACJA_DODATKOWA_POLE_WPIS.INFORMACJA_WPIS_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long informacjaWpisId;

    /**
     * INFORMACJA_DODATKOWA_POLE_WPIS.POLE_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long poleId;

    /**
     * INFORMACJA_DODATKOWA_POLE_WPIS.NIE_PRZYPOMINAJ
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Boolean niePrzypominaj;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return INFORMACJA_DODATKOWA_POLE_WPIS.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * INFORMACJA_DODATKOWA_POLE_WPIS.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return INFORMACJA_DODATKOWA_POLE_WPIS.INFORMACJA_WPIS_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getInformacjaWpisId() {
        return informacjaWpisId;
    }

    /**
     * INFORMACJA_DODATKOWA_POLE_WPIS.INFORMACJA_WPIS_ID
     *
     * @param informacjaWpisId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setInformacjaWpisId(Long informacjaWpisId) {
        this.informacjaWpisId = informacjaWpisId;
    }

    /**
     * @return INFORMACJA_DODATKOWA_POLE_WPIS.POLE_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPoleId() {
        return poleId;
    }

    /**
     * INFORMACJA_DODATKOWA_POLE_WPIS.POLE_ID
     *
     * @param poleId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPoleId(Long poleId) {
        this.poleId = poleId;
    }

    /**
     * @return INFORMACJA_DODATKOWA_POLE_WPIS.NIE_PRZYPOMINAJ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Boolean getNiePrzypominaj() {
        return niePrzypominaj;
    }

    /**
     * INFORMACJA_DODATKOWA_POLE_WPIS.NIE_PRZYPOMINAJ
     *
     * @param niePrzypominaj
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNiePrzypominaj(Boolean niePrzypominaj) {
        this.niePrzypominaj = niePrzypominaj;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        InformacjaDodatkowaPoleWpis other = (InformacjaDodatkowaPoleWpis) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getInformacjaWpisId() == null ? other.getInformacjaWpisId() == null : this.getInformacjaWpisId().equals(other.getInformacjaWpisId()))
            && (this.getPoleId() == null ? other.getPoleId() == null : this.getPoleId().equals(other.getPoleId()))
            && (this.getNiePrzypominaj() == null ? other.getNiePrzypominaj() == null : this.getNiePrzypominaj().equals(other.getNiePrzypominaj()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getInformacjaWpisId() == null) ? 0 : getInformacjaWpisId().hashCode());
        result = prime * result + ((getPoleId() == null) ? 0 : getPoleId().hashCode());
        result = prime * result + ((getNiePrzypominaj() == null) ? 0 : getNiePrzypominaj().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", informacjaWpisId=").append(informacjaWpisId);
        sb.append(", poleId=").append(poleId);
        sb.append(", niePrzypominaj=").append(niePrzypominaj);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/InformacjaDodatkowaPoleWpis.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class InformacjaDodatkowaPoleWpis extends GenericDPSObject {
    /**
     * INFORMACJA_DODATKOWA_POLE_WPIS.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * INFORMACJA_DODATKOWA_POLE_WPIS.INFORMACJA_WPIS_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long informacjaWpisId;

    /**
     * INFORMACJA_DODATKOWA_POLE_WPIS.POLE_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long poleId;

    /**
     * INFORMACJA_DODATKOWA_POLE_WPIS.NIE_PRZYPOMINAJ
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Boolean niePrzypominaj;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return INFORMACJA_DODATKOWA_POLE_WPIS.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * INFORMACJA_DODATKOWA_POLE_WPIS.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return INFORMACJA_DODATKOWA_POLE_WPIS.INFORMACJA_WPIS_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getInformacjaWpisId() {
        return informacjaWpisId;
    }

    /**
     * INFORMACJA_DODATKOWA_POLE_WPIS.INFORMACJA_WPIS_ID
     *
     * @param informacjaWpisId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setInformacjaWpisId(Long informacjaWpisId) {
        this.informacjaWpisId = informacjaWpisId;
    }

    /**
     * @return INFORMACJA_DODATKOWA_POLE_WPIS.POLE_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPoleId() {
        return poleId;
    }

    /**
     * INFORMACJA_DODATKOWA_POLE_WPIS.POLE_ID
     *
     * @param poleId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPoleId(Long poleId) {
        this.poleId = poleId;
    }

    /**
     * @return INFORMACJA_DODATKOWA_POLE_WPIS.NIE_PRZYPOMINAJ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Boolean getNiePrzypominaj() {
        return niePrzypominaj;
    }

    /**
     * INFORMACJA_DODATKOWA_POLE_WPIS.NIE_PRZYPOMINAJ
     *
     * @param niePrzypominaj
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNiePrzypominaj(Boolean niePrzypominaj) {
        this.niePrzypominaj = niePrzypominaj;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        InformacjaDodatkowaPoleWpis other = (InformacjaDodatkowaPoleWpis) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getInformacjaWpisId() == null ? other.getInformacjaWpisId() == null : this.getInformacjaWpisId().equals(other.getInformacjaWpisId()))
            && (this.getPoleId() == null ? other.getPoleId() == null : this.getPoleId().equals(other.getPoleId()))
            && (this.getNiePrzypominaj() == null ? other.getNiePrzypominaj() == null : this.getNiePrzypominaj().equals(other.getNiePrzypominaj()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getInformacjaWpisId() == null) ? 0 : getInformacjaWpisId().hashCode());
        result = prime * result + ((getPoleId() == null) ? 0 : getPoleId().hashCode());
        result = prime * result + ((getNiePrzypominaj() == null) ? 0 : getNiePrzypominaj().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", informacjaWpisId=").append(informacjaWpisId);
        sb.append(", poleId=").append(poleId);
        sb.append(", niePrzypominaj=").append(niePrzypominaj);
        sb.append("]");
        return sb.toString();
    }
}
